javauis/mmapi_qt/baseline/javasrc.emc/com/nokia/microedition/media/ManagerImpl.java
changeset 48 e0d6e9bd3ca7
parent 35 85266cc22c7f
child 56 abc41079b313
--- a/javauis/mmapi_qt/baseline/javasrc.emc/com/nokia/microedition/media/ManagerImpl.java	Wed Jun 23 18:07:10 2010 +0300
+++ b/javauis/mmapi_qt/baseline/javasrc.emc/com/nokia/microedition/media/ManagerImpl.java	Tue Jul 06 14:10:26 2010 +0300
@@ -468,25 +468,25 @@
         }
         InternalPlayer player =null;
         /// Implementation done for java ui 3.x req
-        // in case of AnimationPlayer, we won't be using the ProtocolFactory class.
-        //
-        Enumeration plugins = iPlugIns.elements();
-        AnimationPlayerFactory apf=null;
-        while (plugins.hasMoreElements() && (player == null))
-        {
-            PlugIn temp = (PlugIn) plugins.nextElement();
-            if (temp instanceof AnimationPlayerFactory)
-            {
-                apf = (AnimationPlayerFactory) temp;
-                break;
-            }
-        }
-        if (apf!=null)
-        {
-            player=apf.createPlayer(aLocator);
-        }
+        // in case of AnimationPlayer file protocol, we won't be using the ProtocolFactory class.
+        // We need to do this kind of work out, only if it is file protocol 
+		if (new Locator(aLocator).getProtocol().equals("file")) {
+			Enumeration plugins = iPlugIns.elements();
+			AnimationPlayerFactory apf = null;
+			while (plugins.hasMoreElements() && (player == null)) {
+				PlugIn temp = (PlugIn) plugins.nextElement();
+				if (temp instanceof AnimationPlayerFactory) {
+					apf = (AnimationPlayerFactory) temp;
+					break;
+				}
+			}
+			if (apf != null) {
+				player = apf.createPlayer(aLocator);
+			}
+		}
         ////////////////////////////////////////////////////////
         // if player is still null, try to create the native player
+		System.out.println("ManagerImpl::createPlayer(String locator )locator is "+aLocator );
         if (player==null)
             player =iProtocolFactory.createPlayer(
                         new Locator(aLocator));